summaryrefslogtreecommitdiff
path: root/train_cmd.c
diff options
context:
space:
mode:
authordarkvater <darkvater@openttd.org>2004-11-14 13:07:07 +0000
committerdarkvater <darkvater@openttd.org>2004-11-14 13:07:07 +0000
commit397cc50f61768c73dd4a1ddea03fd5e763d85b50 (patch)
tree19e28ad2c07c2774c4b799f431c2acffe63d655a /train_cmd.c
parent8946e92468db588a1a0d39da2b9a53523e091d10 (diff)
downloadopenttd-397cc50f61768c73dd4a1ddea03fd5e763d85b50.tar.xz
(svn r587) -newgrf: Rename all /Checkpoint/i tokens to 'Waypoint's. The name actually makes some sense and is also compatible with TTDPatch (pasky).
Diffstat (limited to 'train_cmd.c')
-rw-r--r--train_cmd.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/train_cmd.c b/train_cmd.c
index 2d28ab63c..0181f6534 100644
--- a/train_cmd.c
+++ b/train_cmd.c
@@ -1582,8 +1582,8 @@ static bool ProcessTrainOrder(Vehicle *v)
v->cur_order_index++;
}
- // check if we've reached the checkpoint?
- if ((v->next_order & OT_MASK) == OT_GOTO_CHECKPOINT && v->tile == v->dest_tile) {
+ // check if we've reached the waypoint?
+ if ((v->next_order & OT_MASK) == OT_GOTO_WAYPOINT && v->tile == v->dest_tile) {
v->cur_order_index++;
}
@@ -1623,8 +1623,8 @@ static bool ProcessTrainOrder(Vehicle *v)
} else if ((order & OT_MASK) == OT_GOTO_DEPOT) {
v->dest_tile = _depots[order >> 8].xy;
result = CheckReverseTrain(v);
- } else if ((order & OT_MASK) == OT_GOTO_CHECKPOINT) {
- v->dest_tile = _checkpoints[order >> 8].xy;
+ } else if ((order & OT_MASK) == OT_GOTO_WAYPOINT) {
+ v->dest_tile = _waypoints[order >> 8].xy;
result = CheckReverseTrain(v);
}